# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.0 - 2026-02-25

Initial release

### Adds

- `IIIFViewer` class, an `anywidget` object for panning and browsing slippy-tile images served from an IIIF source.
